@@ -4,7 +4,7 @@ from django.db import models
 from django.utils import timezone
 
 from puddl.contrib.file.models import File
-from puddl.felix.bash_history.lib import iter_bash_history
+from .lib import iter_bash_history
 from puddl.models import Datum
 
 log = logging.getLogger(__name__)
