@@ -1,15 +1,13 @@
 from sqlalchemy import Column, Integer, Text, String, ForeignKey, UniqueConstraint, \
     BigInteger
 from sqlalchemy.dialects import postgresql
-from sqlalchemy.ext.declarative import declarative_base
 from sqlalchemy.orm import relationship
 
+from puddl.db.alchemy import Schema
 
-class Base:
-    __table_args__ = {"schema": "codimd"}
+schema = Schema('codimd')
 
-
-Base = declarative_base(cls=Base)
+Base = schema.declarative_base()
 
 
 # https://docs.sqlalchemy.org/en/13/orm/tutorial.html
